diff --git a/install/dist/lib/gentoo.lib.php b/install/dist/lib/gentoo.lib.php
index 03165e67ff12f5d76a2ccc576ddf450603629984..f7a0df1d7f77da27b031427cf3f87e427250e1a2 100644
--- a/install/dist/lib/gentoo.lib.php
+++ b/install/dist/lib/gentoo.lib.php
@@ -653,7 +653,7 @@ class installer extends installer_base
 			
 			// PHP-FPM
 			// Dont just copy over the php-fpm pool template but add some custom settings
-			$content = rf('tpl/php_fpm_pool.conf.master');
+			$content = rf('tpl/apps_php_fpm_pool.conf.master');
 			$content = str_replace('{fpm_pool}', 'apps', $content);
 			$content = str_replace('{fpm_port}', ($conf['nginx']['php_fpm_start_port']+1), $content);
 			$content = str_replace('{fpm_user}', $apps_vhost_user, $content);
diff --git a/install/lib/installer_base.lib.php b/install/lib/installer_base.lib.php
index 197aee38916483c1ef4edf8bde712088f0561ed0..f145e243631b60c662003c34e585b15fa2e61193 100644
--- a/install/lib/installer_base.lib.php
+++ b/install/lib/installer_base.lib.php
@@ -1483,7 +1483,7 @@ class installer_base {
 			
 			// PHP-FPM
 			// Dont just copy over the php-fpm pool template but add some custom settings
-			$content = rf('tpl/php_fpm_pool.conf.master');
+			$content = rf('tpl/apps_php_fpm_pool.conf.master');
 			$content = str_replace('{fpm_pool}', 'apps', $content);
 			$content = str_replace('{fpm_port}', ($conf['nginx']['php_fpm_start_port']+1), $content);
 			$content = str_replace('{fpm_user}', $apps_vhost_user, $content);
diff --git a/install/tpl/apps_php_fpm_pool.conf.master b/install/tpl/apps_php_fpm_pool.conf.master
new file mode 100644
index 0000000000000000000000000000000000000000..b5000e70b8d6710d9807db6552a7837c3e0083e0
--- /dev/null
+++ b/install/tpl/apps_php_fpm_pool.conf.master
@@ -0,0 +1,18 @@
+[{fpm_pool}]
+
+listen = 127.0.0.1:{fpm_port}
+
+listen.allowed_clients = 127.0.0.1
+
+user = {fpm_user}
+group = {fpm_group}
+
+pm = dynamic
+pm.max_children = 50
+pm.start_servers = 20
+pm.min_spare_servers = 5
+pm.max_spare_servers = 35
+
+chdir = /
+
+php_admin_flag[magic_quotes_gpc] = off
\ No newline at end of file
diff --git a/install/tpl/nginx_apps.vhost.master b/install/tpl/nginx_apps.vhost.master
index b0bd3a3e2106fff04688601942b3764aa09b2566..0ba7fc2b08400c8ced2d7ffbdd1b388cc08884a0 100644
--- a/install/tpl/nginx_apps.vhost.master
+++ b/install/tpl/nginx_apps.vhost.master
@@ -30,4 +30,42 @@ server {
         location ~ /\. {
                deny  all;
         }
+
+        location /phpmyadmin {
+               root /usr/share/;
+               index index.php index.html index.htm;
+               location ~ ^/phpmyadmin/(.+\.php)$ {
+                       try_files $uri =404;
+                       root /usr/share/;
+                       include /etc/nginx/fastcgi_params;
+                       fastcgi_pass 127.0.0.1:{fpm_port};
+                       fastcgi_index index.php;
+                       fastcgi_param SCRIPT_FILENAME $request_filename;
+               }
+               location ~* ^/phpmyadmin/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
+                       root /usr/share/;
+               }
+        }
+        location /phpMyAdmin {
+               rewrite ^/* /phpmyadmin last;
+        }
+		
+        location /squirrelmail {
+               root /usr/share/;
+               index index.php index.html index.htm;
+               location ~ ^/squirrelmail/(.+\.php)$ {
+                       try_files $uri =404;
+                       root /usr/share/;
+                       include /etc/nginx/fastcgi_params;
+                       fastcgi_pass 127.0.0.1:{fpm_port};
+                       fastcgi_index index.php;
+                       fastcgi_param SCRIPT_FILENAME $request_filename;
+               }
+               location ~* ^/squirrelmail/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
+                       root /usr/share/;
+               }
+        }
+        location /webmail {
+               rewrite ^/* /squirrelmail last;
+        }
 }
\ No newline at end of file
diff --git a/install/tpl/nginx_ispconfig.vhost.master b/install/tpl/nginx_ispconfig.vhost.master
index ffaf7607f5e5d1405c52c89a58482f93fb06972a..967fba9063a58e2be9c4f91296d1e802111e0be0 100644
--- a/install/tpl/nginx_ispconfig.vhost.master
+++ b/install/tpl/nginx_ispconfig.vhost.master
@@ -33,43 +33,43 @@ server {
                deny  all;
         }
 		
-        location /phpmyadmin {
-               root /usr/share/;
-               index index.php index.html index.htm;
-               location ~ ^/phpmyadmin/(.+\.php)$ {
-                       try_files $uri =404;
-                       root /usr/share/;
-                       include /etc/nginx/fastcgi_params;
-                       fastcgi_pass 127.0.0.1:{fpm_port};
-                       {ssl_comment}fastcgi_param  HTTPS {fastcgi_ssl};
-                       fastcgi_index index.php;
-                       fastcgi_param SCRIPT_FILENAME $request_filename;
-               }
-               location ~* ^/phpmyadmin/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
-                       root /usr/share/;
-               }
-        }
-        location /phpMyAdmin {
-               rewrite ^/* /phpmyadmin last;
-        }
-		
-        location /squirrelmail {
-               root /usr/share/;
-               index index.php index.html index.htm;
-               location ~ ^/squirrelmail/(.+\.php)$ {
-                       try_files $uri =404;
-                       root /usr/share/;
-                       include /etc/nginx/fastcgi_params;
-                       fastcgi_pass 127.0.0.1:{fpm_port};
-                       {ssl_comment}fastcgi_param  HTTPS {fastcgi_ssl};
-                       fastcgi_index index.php;
-                       fastcgi_param SCRIPT_FILENAME $request_filename;
-               }
-               location ~* ^/squirrelmail/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
-                       root /usr/share/;
-               }
-        }
-        location /webmail {
-               rewrite ^/* /squirrelmail last;
-        }
+#        location /phpmyadmin {
+#               root /usr/share/;
+#               index index.php index.html index.htm;
+#               location ~ ^/phpmyadmin/(.+\.php)$ {
+#                       try_files $uri =404;
+#                       root /usr/share/;
+#                       include /etc/nginx/fastcgi_params;
+#                       fastcgi_pass 127.0.0.1:{fpm_port};
+#                       {ssl_comment}fastcgi_param  HTTPS {fastcgi_ssl};
+#                       fastcgi_index index.php;
+#                       fastcgi_param SCRIPT_FILENAME $request_filename;
+#               }
+#               location ~* ^/phpmyadmin/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
+#                       root /usr/share/;
+#               }
+#        }
+#        location /phpMyAdmin {
+#               rewrite ^/* /phpmyadmin last;
+#        }
+#		
+#        location /squirrelmail {
+#               root /usr/share/;
+#               index index.php index.html index.htm;
+#               location ~ ^/squirrelmail/(.+\.php)$ {
+#                       try_files $uri =404;
+#                       root /usr/share/;
+#                       include /etc/nginx/fastcgi_params;
+#                       fastcgi_pass 127.0.0.1:{fpm_port};
+#                       {ssl_comment}fastcgi_param  HTTPS {fastcgi_ssl};
+#                       fastcgi_index index.php;
+#                       fastcgi_param SCRIPT_FILENAME $request_filename;
+#               }
+#               location ~* ^/squirrelmail/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
+#                       root /usr/share/;
+#               }
+#        }
+#        location /webmail {
+#               rewrite ^/* /squirrelmail last;
+#        }
 }
\ No newline at end of file
diff --git a/server/conf/nginx_apps.vhost.master b/server/conf/nginx_apps.vhost.master
index b0bd3a3e2106fff04688601942b3764aa09b2566..0ba7fc2b08400c8ced2d7ffbdd1b388cc08884a0 100644
--- a/server/conf/nginx_apps.vhost.master
+++ b/server/conf/nginx_apps.vhost.master
@@ -30,4 +30,42 @@ server {
         location ~ /\. {
                deny  all;
         }
+
+        location /phpmyadmin {
+               root /usr/share/;
+               index index.php index.html index.htm;
+               location ~ ^/phpmyadmin/(.+\.php)$ {
+                       try_files $uri =404;
+                       root /usr/share/;
+                       include /etc/nginx/fastcgi_params;
+                       fastcgi_pass 127.0.0.1:{fpm_port};
+                       fastcgi_index index.php;
+                       fastcgi_param SCRIPT_FILENAME $request_filename;
+               }
+               location ~* ^/phpmyadmin/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
+                       root /usr/share/;
+               }
+        }
+        location /phpMyAdmin {
+               rewrite ^/* /phpmyadmin last;
+        }
+		
+        location /squirrelmail {
+               root /usr/share/;
+               index index.php index.html index.htm;
+               location ~ ^/squirrelmail/(.+\.php)$ {
+                       try_files $uri =404;
+                       root /usr/share/;
+                       include /etc/nginx/fastcgi_params;
+                       fastcgi_pass 127.0.0.1:{fpm_port};
+                       fastcgi_index index.php;
+                       fastcgi_param SCRIPT_FILENAME $request_filename;
+               }
+               location ~* ^/squirrelmail/(.+\.(jpg|jpeg|gif|css|png|js|ico|html|xml|txt))$ {
+                       root /usr/share/;
+               }
+        }
+        location /webmail {
+               rewrite ^/* /squirrelmail last;
+        }
 }
\ No newline at end of file
diff --git a/install/dist/lib/fedora.lib.php b/install/dist/lib/fedora.lib.php
index 4389534f7e5afa9732a7fd8be5426477669a06b9..dc9ce432d0bd1725c7c4d61699ad1a2880f168c7 100644
--- a/install/dist/lib/fedora.lib.php
+++ b/install/dist/lib/fedora.lib.php
@@ -861,8 +861,8 @@ class installer_dist extends installer_base {
 		if($conf['nginx']['installed'] == true){
 			$command = 'usermod -a -G ispconfig '.$conf['nginx']['user'];
 			caselog($command.' &> /dev/null', __FILE__, __LINE__, "EXECUTED: $command", "Failed to execute the command $command");
-			// Allow the ISPConfig vhost access to /etc/squirrelmail
-			$command = 'usermod -a -G '.$conf['apache']['group'].' ispconfig';
+			// Allow the ispapps vhost access to /etc/squirrelmail
+			$command = 'usermod -a -G '.$conf['apache']['group'].' ispapps';
 			caselog($command.' &> /dev/null', __FILE__, __LINE__, "EXECUTED: $command", "Failed to execute the command $command");
 		}
 		